@@ -4,7 +4,7 @@
 # also regenerates all aclocal.m4, config.h.in, Makefile.in, configure files
 # with new versions of autoconf or automake.
 #
-# This script requires autoconf-2.63 and automake-1.11 in the PATH.
+# This script requires autoconf-2.63..2.69 and automake-1.11..1.12 in the PATH.
 # It also requires either
 #   - the GNULIB_TOOL environment variable pointing to the gnulib-tool script
 #     in a gnulib checkout, or
@@ -12,7 +12,7 @@
 # It also requires
 #   - the gperf program.
 
-# Copyright (C) 2003-2009 Free Software Foundation, Inc.
+# Copyright (C) 2003-2012 Free Software Foundation, Inc.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -60,12 +60,6 @@ if test $skip_gnulib = false; then
   fi
   # Skip the gnulib-tool step if gnulib-tool was not found.
   if test -n "$GNULIB_TOOL"; then
-    if test -f srcm4/gnulib-cache.m4; then
-      mv -f srcm4/gnulib-cache.m4 srcm4/gnulib-cache.m4~
-    fi
-    if test -f srclib/Makefile.gnulib; then
-      mv -f srclib/Makefile.gnulib srclib/Makefile.gnulib~
-    fi
     make -f Makefile.devel srclib/Makefile.gnulib GNULIB_TOOL="$GNULIB_TOOL"
   fi
 fi
