@@ -1,10 +1,10 @@
-/* Copyright (C) 1999-2002 Free Software Foundation, Inc.
+/* Copyright (C) 1999-2002, 2011-2012 Free Software Foundation, Inc.
    This file is part of the GNU LIBICONV Tools.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 /*
  * Generates an 8-bit character set table from a .TXT table as found on
@@ -59,6 +58,9 @@
  *   ./8bit_tab_to_h ISO-8859-15 iso8859_15 < 8859-15.TXT
  *   ./8bit_tab_to_h JISX0201.1976-0 jisx0201 < JIS0201.TXT
  *   ./8bit_tab_to_h KOI8-R koi8_r < KOI8-R.TXT
+ *
+ *   ./8bit_tab_to_h 'CP50221 JISX0208 extensions' cp50221_0208_ext < CP50221-0208-EXT.TXT
+ *   ./8bit_tab_to_h 'CP50221 JISX0212 extensions' cp50221_0212_ext < CP50221-0212-EXT.TXT
  */
 
 #include <stdio.h>
@@ -159,8 +161,7 @@ int main (int argc, char *argv[])
     fprintf(f, " *\n");
     fprintf(f, " * You should have received a copy of the GNU Library General Public\n");
     fprintf(f, " * License along with the GNU LIBICONV Library; see the file COPYING.LIB.\n");
-    fprintf(f, " * If not, write to the Free Software Foundation, Inc., 51 Franklin Street,\n");
-    fprintf(f, " * Fifth Floor, Boston, MA 02110-1301, USA.\n");
+    fprintf(f, " * If not, see <http://www.gnu.org/licenses/>.\n");
     fprintf(f, " */\n");
     fprintf(f, "\n");
     fprintf(f, "/*\n");
