@@ -1,10 +1,10 @@
-/* Copyright (C) 1999-2004 Free Software Foundation, Inc.
+/* Copyright (C) 1999-2004, 2006-2007, 2010, 2012 Free Software Foundation, Inc.
    This file is part of the GNU LIBICONV Tools.
 
-   This program is free software; you can redistribute it and/or modify
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -12,8 +12,7 @@
    GNU General Public License for more details.
 
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software Foundation,
-   Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.  */
+   along with this program; if not, see <http://www.gnu.org/licenses/>.  */
 
 /*
  * Generates a CJK character set table from a .TXT table as found on
@@ -76,7 +75,7 @@ typedef struct {
 static void output_title (const char *charsetname)
 {
   printf("/*\n");
-  printf(" * Copyright (C) 1999-2004 Free Software Foundation, Inc.\n");
+  printf(" * Copyright (C) 1999-2010 Free Software Foundation, Inc.\n");
   printf(" * This file is part of the GNU LIBICONV Library.\n");
   printf(" *\n");
   printf(" * The GNU LIBICONV Library is free software; you can redistribute it\n");
@@ -91,8 +90,7 @@ static void output_title (const char *charsetname)
   printf(" *\n");
   printf(" * You should have received a copy of the GNU Library General Public\n");
   printf(" * License along with the GNU LIBICONV Library; see the file COPYING.LIB.\n");
-  printf(" * If not, write to the Free Software Foundation, Inc., 51 Franklin Street,\n");
-  printf(" * Fifth Floor, Boston, MA 02110-1301, USA.\n");
+  printf(" * If not, see <http://www.gnu.org/licenses/>.\n");
   printf(" */\n");
   printf("\n");
   printf("/*\n");
@@ -822,9 +820,9 @@ static void output_uni2charset_sparse (const char* name, Encoding* enc, bool mon
   printf("      if (used & ((unsigned short) 1 << i)) {\n");
   if (monotonic || !is_large)
     printf("        unsigned short c;\n");
-  printf("        /* Keep in `used' only the bits 0..i-1. */\n");
+  printf("        /* Keep in 'used' only the bits 0..i-1. */\n");
   printf("        used &= ((unsigned short) 1 << i) - 1;\n");
-  printf("        /* Add `summary->indx' and the number of bits set in `used'. */\n");
+  printf("        /* Add 'summary->indx' and the number of bits set in 'used'. */\n");
   printf("        used = (used & 0x5555) + ((used & 0xaaaa) >> 1);\n");
   printf("        used = (used & 0x3333) + ((used & 0xcccc) >> 2);\n");
   printf("        used = (used & 0x0f0f) + ((used & 0xf0f0) >> 4);\n");
@@ -1821,7 +1819,7 @@ static void do_jisx0213 (const char* name)
         if ((count % 8) == 0) printf(" ");
         printf(" ");
         sprintf(buf,"0x%04x",pagestart[i]);
-        if (strlen(buf) < 7) printf("%*s",7-strlen(buf),"");
+        if (strlen(buf) < 7) printf("%*s",(int)(7-strlen(buf)),"");
         printf("%s,",buf);
         count++;
         if ((count % 8) == 0) printf("\n");
@@ -2070,9 +2068,9 @@ static void do_jisx0213 (const char* name)
   printf("      unsigned short used = summary->used;\n");
   printf("      unsigned int i = ucs & 0x0f;\n");
   printf("      if (used & ((unsigned short) 1 << i)) {\n");
-  printf("        /* Keep in `used' only the bits 0..i-1. */\n");
+  printf("        /* Keep in 'used' only the bits 0..i-1. */\n");
   printf("        used &= ((unsigned short) 1 << i) - 1;\n");
-  printf("        /* Add `summary->indx' and the number of bits set in `used'. */\n");
+  printf("        /* Add 'summary->indx' and the number of bits set in 'used'. */\n");
   printf("        used = (used & 0x5555) + ((used & 0xaaaa) >> 1);\n");
   printf("        used = (used & 0x3333) + ((used & 0xcccc) >> 2);\n");
   printf("        used = (used & 0x0f0f) + ((used & 0xf0f0) >> 4);\n");
@@ -2130,7 +2128,8 @@ int main (int argc, char *argv[])
     do_uhc_2(name);
   else if (!strcmp(name,"big5") || !strcmp(name,"cp950ext"))
     do_big5(name);
-  else if (!strcmp(name,"hkscs"))
+  else if (!strcmp(name,"hkscs1999") || !strcmp(name,"hkscs2001")
+           || !strcmp(name,"hkscs2004") || !strcmp(name,"hkscs2008"))
     do_hkscs(name);
   else if (!strcmp(name,"johab_hangul"))
     do_johab_hangul(name);
